
=================
API documentation
=================

The package consists of two major subpackages

* the :py:mod:`pninexus.h5cpp` which is a thin wrapper around the *h5cpp* library
* and :py:mod:`pninexus.nexus` which wraps classes and functions from the
  :cpp:any:`pni::nexus` namespace of *libpninexus*.

The ``pninexus.h5cpp`` package
==============================

.. automodule:: pninexus.h5cpp
   :noindex:
		
.. toctree::
   :maxdepth: 1

   h5cpp/h5cpp
   h5cpp/attributes
   h5cpp/dataspace
   h5cpp/datatype
   h5cpp/file
   h5cpp/properties
   h5cpp/node






The ``pninexus.nexus`` package
==============================

.. automodule:: pninexus.nexus
   :noindex:

.. toctree::
   :maxdepth: 1

   nexus/files
   nexus/factories
